@@ -1,10 +1,13 @@
 import os
+from typing import ClassVar
 
 from datagen import modalities
 from datagen.components.datapoint.entity import base
 
 
 class DataPoint(base.DataPoint):
+    PLUGINS_GROUP_NAME: ClassVar[str] = "datagen.plugins.datapoints.hic"
+
     @modalities.textual_modality
     def actor_metadata(self) -> modalities.TextualModality:
         return modalities.TextualModality(factory_name="actors", file_name="actor_metadata.json")
