@@ -29,10 +29,6 @@ class DataPoint(base.DataPoint):
             pre_process=CreateV1AllKeypointsFile(self),
         )
 
-    @modalities.textual_modality
-    def lights_metadata(self) -> modalities.TextualModality:
-        return modalities.TextualModality(factory_name="lights_metadata", file_name="lights_metadata.json")
-
     @modalities.textual_modality
     def _datapoint_request(self) -> modalities.TextualModality:
         """
