@@ -31,13 +31,6 @@ class KeypointsModalityContainer(containers.DeclarativeContainer):
     )
 
 
-class LightsMetadataModalityContainer(containers.DeclarativeContainer):
-
-    from .lights_metadata import LightsMetadata
-
-    create = providers.FactoryAggregate({1: modality_dataclass_factory(clazz=LightsMetadata)})
-
-
 class DatapointRequestModalityContainer(containers.DeclarativeContainer):
 
     from datagen.api.assets import DataRequest
@@ -56,10 +49,6 @@ class IdentitiesModalitiesContainer(BaseModalitiesContainer):
 
     keypoints = providers.Callable(modality_factory, modality_container=providers.Container(KeypointsModalityContainer))
 
-    lights_metadata = providers.Callable(
-        modality_factory, modality_container=providers.Container(LightsMetadataModalityContainer)
-    )
-
     datapoint_request = providers.Callable(
         modality_factory, modality_container=providers.Container(DatapointRequestModalityContainer)
     )
